@@ -31,7 +31,7 @@ class SsoStrategy:
         'provision_group_inclusion': None,     # string - Comma-separated list of group names for groups (with optional wildcards) that will be auto-provisioned.
         'provision_group_required': None,     # string - Comma or newline separated list of group names (with optional wildcards) to require membership for user provisioning.
         'provision_site_admin_groups': None,     # string - Comma-separated list of group names whose members will be created as Site Admins.
-        'provision_attachments_permission': None,     # boolean - Auto-provisioned users get Sharing permission?
+        'provision_attachments_permission': None,     # boolean - DEPRECATED: Auto-provisioned users get Sharing permission. Use a Group with the Bundle permission instead.
         'provision_dav_permission': None,     # boolean - Auto-provisioned users get WebDAV permission?
         'provision_ftp_permission': None,     # boolean - Auto-provisioned users get FTP permission?
         'provision_sftp_permission': None,     # boolean - Auto-provisioned users get SFTP permission?
@@ -69,6 +69,10 @@ class SsoStrategy:
 #   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 def list(params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "per_page" in params and not isinstance(params["per_page"], int):
